@@ -95,6 +95,19 @@ impl InputPrompt<'_, '_> {
 
         None
     }
+
+    fn check_complete_default(&mut self) -> bool {
+        if self.get_remaining_default().is_some() {
+            let (default, default_len) = self.input_opts.default.as_ref().unwrap();
+            self.input.set_value(default.clone());
+            self.input.set_at(*default_len);
+            self.is_valid = true;
+
+            true
+        } else {
+            false
+        }
+    }
 }
 
 impl Widget for InputPrompt<'_, '_> {
@@ -192,11 +205,7 @@ impl Widget for InputPrompt<'_, '_> {
                     });
                     return true;
                 }
-            } else if self.get_remaining_default().is_some() {
-                let (default, default_len) = self.input_opts.default.as_ref().unwrap();
-                self.input.set_value(default.clone());
-                self.input.set_at(*default_len);
-                self.is_valid = true;
+            } else if self.check_complete_default() {
                 return true;
             }
         }
@@ -208,6 +217,8 @@ impl Widget for InputPrompt<'_, '_> {
 
             self.select = None;
             return true;
+        } else if key.code == KeyCode::Right && self.check_complete_default() {
+            return true;
         }
 
         self.maybe_select_op(|select| select.handle_key(key))
@@ -225,11 +236,13 @@ impl Prompt for InputPrompt<'_, '_> {
     type Output = String;
 
     fn finish(self) -> Self::Output {
-        let prompt = self.prompt;
-        let mut ans = self
-            .input
-            .finish()
-            .unwrap_or_else(|| prompt.into_hint().unwrap_or_else(String::new));
+        let mut ans = self.input.finish();
+
+        if ans.is_empty() {
+            if let Some((default, _)) = self.input_opts.default {
+                ans = default;
+            }
+        }
 
         if let Filter::Sync(filter) = self.input_opts.filter {
             ans = filter(ans, self.answers);
@@ -244,7 +257,7 @@ impl Prompt for InputPrompt<'_, '_> {
             return Ok(Validation::Continue);
         }
 
-        if !self.input.has_value() && self.prompt.hint().is_some() {
+        if self.input.value().is_empty() && self.input_opts.default.is_some() {
             return Ok(Validation::Finish);
         }
 
@@ -271,23 +284,18 @@ impl<'i> Input<'i> {
     pub(crate) fn ask<B: Backend, E: EventIterator>(
         mut self,
         message: String,
+        on_esc: ui::OnEsc,
         answers: &Answers,
         b: &mut B,
         events: &mut E,
-    ) -> ui::Result<Answer> {
+    ) -> ui::Result<Option<Answer>> {
         let transform = self.transform.take();
 
-        let ans = ui::Input::new(self.into_input_prompt(&message, answers), b).run(events)?;
+        let ans = ui::Input::new(self.into_input_prompt(&message, answers), b)
+            .on_esc(on_esc)
+            .run(events)?;
 
-        crate::write_final!(
-            transform,
-            message,
-            &ans,
-            answers,
-            b,
-            b.write_styled(&ans.as_str().cyan())?
-        );
-
-        Ok(Answer::String(ans))
+        crate::write_final!(transform, message, ans [ref], answers, b, |ans| b
+            .write_styled(&ans.as_str().cyan())?)
     }
 }
