@@ -206,29 +206,23 @@ impl<'a> RawSelect<'a> {
     pub(crate) fn ask<B: Backend, E: EventIterator>(
         mut self,
         message: String,
+        on_esc: ui::OnEsc,
         answers: &Answers,
         b: &mut B,
         events: &mut E,
-    ) -> ui::Result<Answer> {
+    ) -> ui::Result<Option<Answer>> {
         let transform = self.transform.take();
 
-        let ans = ui::Input::new(self.into_prompt(&message), b).run(events)?;
+        let ans = ui::Input::new(self.into_prompt(&message), b)
+            .on_esc(on_esc)
+            .run(events)?;
 
-        crate::write_final!(
-            transform,
-            message,
-            &ans,
-            answers,
-            b,
-            b.write_styled(
-                &ans.text
-                    .lines()
-                    .next()
-                    .expect("There must be at least one line in a `str`")
-                    .cyan()
-            )?
-        );
-
-        Ok(Answer::ListItem(ans))
+        crate::write_final!(transform, message, ans [ref], answers, b, |ans| b.write_styled(
+            &ans.text
+                .lines()
+                .next()
+                .expect("There must be at least one line in a `str`")
+                .cyan()
+        )?)
     }
 }
