@@ -111,7 +111,7 @@ fn test_default() {
     ]);
 
     let ans = requestty::prompt_one_with(prompt, &mut backend, &mut events).unwrap();
-    assert_eq!(ans, Answer::String("".into()));
+    assert_eq!(ans, Answer::String("default".into()));
 
     let prompt = Question::input("name")
         .message("message")
@@ -121,7 +121,7 @@ fn test_default() {
     let mut events = TestEvents::new(Some(KeyCode::Enter.into()));
 
     let ans = requestty::prompt_one_with(prompt, &mut backend, &mut events).unwrap();
-    assert_eq!(ans, Answer::String("".into()));
+    assert_eq!(ans, Answer::String("default".into()));
 
     let prompt = Question::input("name")
         .message("message")
@@ -132,6 +132,16 @@ fn test_default() {
 
     let ans = requestty::prompt_one_with(prompt, &mut backend, &mut events).unwrap();
     assert_eq!(ans, Answer::String("default".into()));
+
+    let prompt = Question::input("name")
+        .message("message")
+        .default("default");
+
+    let mut backend = helpers::SnapshotOnFlushBackend::new((50, 20).into());
+    let mut events = TestEvents::new(vec![KeyCode::Right.into(), KeyCode::Enter.into()]);
+
+    let ans = requestty::prompt_one_with(prompt, &mut backend, &mut events).unwrap();
+    assert_eq!(ans, Answer::String("default".into()));
 }
 
 #[test]
@@ -166,3 +176,38 @@ fn test_auto_complete() {
     let ans = requestty::prompt_one_with(prompt, &mut backend, &mut events).unwrap();
     assert_eq!(ans, Answer::String("string".into()));
 }
+
+#[test]
+fn test_on_esc() {
+    let size = (50, 20).into();
+    let mut backend = helpers::SnapshotOnFlushBackend::new(size);
+    let mut events = TestEvents::new(Some(KeyCode::Esc.into()));
+
+    let res = requestty::prompt_one_with(
+        Question::input("name")
+            .message("message")
+            .on_esc(requestty::OnEsc::Terminate),
+        &mut backend,
+        &mut events,
+    );
+
+    assert!(matches!(res, Err(requestty::ErrorKind::Aborted)));
+
+    let size = (50, 20).into();
+    let mut backend = helpers::SnapshotOnFlushBackend::new(size);
+    let mut events = TestEvents::new(Some(KeyCode::Esc.into()));
+
+    let res = requestty::prompt_with(
+        Some(
+            Question::input("name")
+                .message("message")
+                .on_esc(requestty::OnEsc::SkipQuestion)
+                .build(),
+        ),
+        &mut backend,
+        &mut events,
+    )
+    .unwrap();
+
+    assert!(res.is_empty());
+}
