@@ -118,4 +118,55 @@ fn test_default() {
 
     let ans = requestty::prompt_one_with(prompt, &mut backend, &mut events).unwrap();
     assert_eq!(ans, Answer::Int(32));
+
+    let prompt = Question::int("name").message("message").default(32);
+
+    let mut backend = helpers::SnapshotOnFlushBackend::new((50, 20).into());
+    let mut events = TestEvents::new(vec![KeyCode::Tab.into(), KeyCode::Enter.into()]);
+
+    let ans = requestty::prompt_one_with(prompt, &mut backend, &mut events).unwrap();
+    assert_eq!(ans, Answer::Int(32));
+
+    let prompt = Question::int("name").message("message").default(32);
+
+    let mut backend = helpers::SnapshotOnFlushBackend::new((50, 20).into());
+    let mut events = TestEvents::new(vec![KeyCode::Right.into(), KeyCode::Enter.into()]);
+
+    let ans = requestty::prompt_one_with(prompt, &mut backend, &mut events).unwrap();
+    assert_eq!(ans, Answer::Int(32));
+}
+
+#[test]
+fn test_on_esc() {
+    let size = (50, 20).into();
+    let mut backend = helpers::SnapshotOnFlushBackend::new(size);
+    let mut events = TestEvents::new(Some(KeyCode::Esc.into()));
+
+    let res = requestty::prompt_one_with(
+        Question::int("name")
+            .message("message")
+            .on_esc(requestty::OnEsc::Terminate),
+        &mut backend,
+        &mut events,
+    );
+
+    assert!(matches!(res, Err(requestty::ErrorKind::Aborted)));
+
+    let size = (50, 20).into();
+    let mut backend = helpers::SnapshotOnFlushBackend::new(size);
+    let mut events = TestEvents::new(Some(KeyCode::Esc.into()));
+
+    let res = requestty::prompt_with(
+        Some(
+            Question::int("name")
+                .message("message")
+                .on_esc(requestty::OnEsc::SkipQuestion)
+                .build(),
+        ),
+        &mut backend,
+        &mut events,
+    )
+    .unwrap();
+
+    assert!(res.is_empty());
 }
